# is_ral()

## How to use

1. ```python
   from colorcodetools.ral.validate import is_ral
   is_ral(ralcode)
   ```
2. ```python
   import colorcodetools
   colorcodetools.ral.validate.is_ral(ralcode)
   ```

## Parameters

1. Required parameters:

   - ral:  
      Enter hex code which should be checked.
     - `type: int`
     - `default: None`
     - `example: 1000`

## Return value

- `type: boolean`
